<?php
/**
 * @package hitsteps
 * @copyright Copyright (c)2013-2022 Armin Nikdel
 * @license GNU General Public License version 3, or later
 * @version $Id: uninstall.hitsteps.php 712 2018-11-05 09:47:53Z  $
 * @since 3.0
 */

// no direct access
defined('_JEXEC') or die('');

class com_hitstepsanalyticsInstallerScript extends ComhitstepsStandardInstallationLibrary
{
	public $parent = null;
	
	public function __construct() {
		$this->_hitsteps_extension		= 'jhitsteps';
		$this->_hitsteps_script_install	= 'install.hitsteps.php';
		$this->_hitsteps_script_update	= 'install.hitsteps.php';
		$this->_hitsteps_script_uninstall	= 'uninstall.hitsteps.php';
	}
}

/**
 * hitsteps.com Standard Installation Library
 */
class ComhitstepsStandardInstallationLibrary {
	
	protected $_hitsteps_extension = '';
	protected $_hitsteps_install_sql_path = '';
	protected $_hitsteps_script_install = '';
	protected $_hitsteps_script_uninstall = '';
	protected $_hitsteps_script_update = '';
	
	/**
	 * Joomla! pre-flight event
	 * 
	 * @param string $type Installation type (install, update, discover_install)
	 * @param JInstaller $parent Parent object
	 */
	public function preflight($type, $parent)
	{
		// Joomla! 1.6/1.7 bugfix for "Can not build admin menus"
		if(in_array($type, array('install','discover_install'))) {
			$this->_bugfixDBFunctionReturnedNoError();
		} else {
			$this->_bugfixCantBuildAdminMenus();
		}
	}
	
	public function install($parent) {
		// Copy the install/uninstall scripts
		$this->_copyLegacyScripts($parent);
		// Load the installation script
		$this->parent = $parent->getParent();
		$this->_scriptLoader($this->_hitsteps_script_install);
	}

	public function update($parent) {
		// Copy the install/uninstall scripts
		$this->_copyLegacyScripts($parent);
		// Load the udpate script
		$this->parent = $parent->getParent();
		$this->_scriptLoader($this->_hitsteps_script_update);
	}
	
	public function uninstall($parent) {
		// Load the uninstallation script
		$this->parent = $parent->getParent();
		$this->_scriptLoader($this->_hitsteps_script_uninstall);
	}
	
	private function _scriptLoader($scriptfile)
	{
		if(!defined('_hitsteps_HACK')) {
			define('_hitsteps_HACK', 1);
		}
		
		if(file_exists($scriptfile)) {
			require_once($scriptfile);
		} elseif(file_exists(dirname(__FILE__).'/'.$scriptfile)) {
			require_once dirname(__FILE__).'/'.$scriptfile;
		}
		else {
			JError::raiseWarning('42', "Installer script file $scriptfile not found.");
		}
	}
	
	/**
	 * Joomla! 1.6+ bugfix for "DB function returned no error"
	 */
	private function _bugfixDBFunctionReturnedNoError()
	{
	
	}
	
	/**
	 * Joomla! 1.6+ bugfix for "Can not build admin menus"
	 */
	private function _bugfixCantBuildAdminMenus()
	{

	}
	

	/**
	 * Copy the legacy install/uninstall scripts to the component's back-end
	 * @param type $parent 
	 */
	private function _copyLegacyScripts($parent)
	{
		$installFile = (string)$parent->getParent()->getManifest()->installfile;
		if ($installFile) {
			$path['src']	= $parent->getParent()->getPath('source') . '/' . $installFile;
			$path['dest']	= $parent->getParent()->getPath('extension_administrator') . '/' . $installFile;
			$parent->getParent()->copyFiles(array ($path));
		}
		
		$uninstallFile = (string)$parent->getParent()->getManifest()->uninstallfile;
		if ($uninstallFile) {
			$path['src']	= $parent->getParent()->getPath('source') . '/' . $uninstallFile;
			$path['dest']	= $parent->getParent()->getPath('extension_administrator') . '/' . $uninstallFile;
			$parent->getParent()->copyFiles(array ($path));
		}
	}
}
